# Ajal Todo CLI

A todo utility - enhanced

## Usage

You should have `uv` installed or have `virtualenv` or `venv` already set up, and using python 3.12+

Run (assuming you are using `uv`):

```shell
uv venv
source .venv/bin/activate
uv sync
```

Now you can run commands, start by running `uv run todo.py --help` and  continue from there
